@@ -26,12 +26,12 @@
 #include "k3baction.h"
 #include "k3bthememanager.h"
 
-#include <KConfigWidgets/KColorScheme>
-#include <KConfigCore/KConfigGroup>
-#include <KConfigCore/KSharedConfig>
+#include <KColorScheme>
+#include <KConfigGroup>
+#include <KSharedConfig>
 #include <KLocalizedString>
-#include <KIOCore/KIO/Global>
-#include <KWidgetsAddons/KMessageBox>
+#include <KIO/Global>
+#include <KMessageBox>
 
 #include <QDebug>
 #include <QEvent>
@@ -52,7 +52,7 @@
 #include <QInputDialog>
 #include <QMenu>
 #include <QStyle>
-#include <QStyleOptionProgressBarV2>
+#include <QStyleOptionProgressBar>
 #include <QToolButton>
 #include <QToolTip>
 #include <QWhatsThis>
@@ -151,7 +151,7 @@ void K3b::FillStatusDisplayWidget::paintEvent( QPaintEvent* )
     }
     const QPen fillPen = KColorScheme( colorGroup, KColorScheme::Selection ).foreground( KColorScheme::NormalText ).color();
 
-    QStyleOptionProgressBarV2 sopb;
+    QStyleOptionProgressBar sopb;
     sopb.direction = layoutDirection();
     sopb.fontMetrics = fontMetrics();
     sopb.palette = palette();
